# HuffPress
## Currently under development
<i><b>huffpress</b></i> - Python library containing Huffman tree and encoding 
algorithms. Including a bespoke compressor
<br><br>
<b>Installation</b><br>

````commandline
pip install huffpress
````
